@@ -2,6 +2,7 @@ from sqlalchemy import Column
 from sqlalchemy import Integer
 from sqlalchemy import ForeignKey
 from sqlalchemy import DateTime
+from sqlalchemy.orm import relationship
 from sqlalchemy import Enum
 from sqlalchemy import func
 from sqlalchemy import String
@@ -9,6 +10,7 @@ from marshmallow import fields
 from marshmallow import Schema
 from marshmallow import post_load
 from enum import Enum as ENUM
+from .order_item import OrderItemSchema
 
 from .base import Base
 
@@ -45,6 +47,8 @@ class Order(Base):
     shipping_method = Column(ForeignKey('shipping_methods.id'), nullable=False)
     payment_method = Column(ForeignKey('payment_methods.id'), nullable=False)
 
+    order_items = relationship('OrderItem', foreign_keys='OrderItem.order_id')
+
 
 class OrderSchema(Schema):
 
@@ -71,6 +75,8 @@ class OrderSchema(Schema):
     shipping_method = fields.Integer(data_key='shippingMethod')
     payment_method = fields.Integer(data_key='paymentMethod')
 
+    order_item = fields.Nested(OrderItemSchema)
+
     @post_load
     def make_address(self, data, **kwargs):
         return Order(**data)
